@@ -12,12 +12,12 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::Git;
 {
-  $Dist::Zilla::PluginBundle::Git::VERSION = '2.009';
+  $Dist::Zilla::PluginBundle::Git::VERSION = '2.023';
 }
 # ABSTRACT: all git plugins in one go
 
 use Moose;
-use Class::MOP;
+use Module::Runtime 'use_module';
 
 with 'Dist::Zilla::Role::PluginBundle';
 
@@ -27,7 +27,7 @@ my @names   = qw{ Check Commit Tag Push };
 my %multi;
 for my $name (@names) {
     my $class = "Dist::Zilla::Plugin::Git::$name";
-    Class::MOP::load_class($class);
+    use_module $class;
     @multi{$class->mvp_multivalue_args} = ();
 }
 
@@ -61,13 +61,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::PluginBundle::Git - all git plugins in one go
 
 =head1 VERSION
 
-version 2.009
+version 2.023
 
 =head1 SYNOPSIS
 
